/*
** cbsmkr.c
**
** dumps cbs files from filename $1 - writes to fname $2
**
** Usage: dumpcbs <infile> <outfile>
**
*/

#include	<stdio.h>
#include	<string.h>

/*
#define LOG(a,b)	fprintf(stderr, a, b);
*/
#define LOG(a, b)	/* null */

#define	ARRAYMAX 512
#define NUL (char)0


/*
** header structure
*/

struct hdr {
	char	cbs[4];
	long	start;
	long	last;
} cbs_hdr;

/*
** record structure
** make it an array so we can read the whole thing in and
** determine the number of files in the CBS file before
** writing them out
*/

struct rec {
	long	index;
	char	fname[512];
	} allrecs[ARRAYMAX];


int main (int argc, char *argv[])
{
	FILE	*ifp, *ofp;
	int		i;
	char	*pos;

	LOG("Starting: argc is %d\n", argc)

	if (argc != 3) 
	{
		fprintf(stderr, "\nUsage: %s <infile> <outfile>\n\n", argv[0]);
		exit(1);
	}
	
	/*
	** open input .cbs file
	*/

	LOG("opening '%s' for read\n", argv[1])
	if ((ifp=fopen(argv[1],"rb"))==NULL) 
	{
		fprintf(stderr, "\nError -2: Could not open '%s' for reading.\n\n",
				argv[1]);
		exit(-2);
	}
	
	/*
	** open output file
	*/

	LOG("opening '%s' for write\n", argv[2])
	if ((ofp=fopen(argv[2],"wb"))==NULL) 
	{
		fprintf(stderr, "\nError -2: Could not open '%s' for writing.\n\n",
				argv[2]);
		exit(-2);
	}

	/*
	** read header
	*/
	LOG("Reading header size: %d\n", sizeof(struct hdr))

	if (fread(&cbs_hdr, sizeof(struct hdr), 1, ifp)!=1)
	{
		fprintf(stderr,"\nError %d: input file header read error\n\n", -3);
		exit(-3);
	}
	LOG("...header is: %s\n", cbs_hdr.cbs);
	LOG("...start is: %d\n", cbs_hdr.start);
	LOG("...last is: %d\n", cbs_hdr.last);

	/*
	** read all records in infile into structures
	*/

	/*
	for(i=0;i<cbs_hdr.last;i++)
	{
		fread(&allrecs[i], sizeof(struct rec), 1, ifp);
		LOG("read record %d\n", i)
		printf("read %d: %s\n",allrecs[i].index,allrecs[i].fname);
	}
	*/

	i=fread(allrecs, sizeof(struct rec), cbs_hdr.last, ifp);

	if (i!=cbs_hdr.last)
	{
		fprintf(stderr,"\nError %d: badly formed record count (%ld) in header\n", 
				-4, cbs_hdr.last);
		exit(-4);
	}

	/*
	** print all records in a form that mkcbs can read
	*/
	for (i=0;i<cbs_hdr.last;i++)
	{
		LOG("loop %d\n",i)
		/*
		** find the strings in fname - change the null terminators to separators
		** Don't change the strings of null to separators
		*/
		
		for (pos=allrecs[i].fname;pos<allrecs[i].fname+510;pos++)
		{
			if (*pos == NUL && *(pos+1) != NUL)
			{
				*pos=';';
			}
		}

		/*
		** print the result to the output file
		*/
		fprintf(ofp,"%ld;%s\n",allrecs[i].index, allrecs[i].fname);
	}

	fclose(ifp);
	fclose(ofp);
	exit(0);

}
