/*
** cbsmkr.c
**
** Makes cbs files from stdin - writes to fname $1
**
** Usage: cbsmkr <outfile.cbs>
**
*/

#include	<stdio.h>
#include	<string.h>
#include	<ctype.h>
/*
#define LOG(a,b)	fprintf(stderr, a, b);
*/
#define LOG(a, b)	/* null */

#define	ARRAYMAX 512
#define NUL	(char) 0

void zero_string(char *in, int len);
int isnumeric(char *str);


/*
** header structure
*/
struct hdr {
	char	cbs[4];
	long	start;
	long	last;
} cbs_hdr;
/*
** record structure
** make it an array so we can read the whole thing in and
** determine the number of files in the CBS file before
** writing them out
*/
struct rec {
	long	index;
	char	fname[512];
} allrecs[ARRAYMAX];


int main(int argc, char *argv[])
{
	FILE	*fp;
	int		i, fnlen;
	char	*pos, *j, tmp[512];

	/*
	** get output file
	*/
	if (argc !=2) 
	{
		fprintf(stderr, "\nUsage: %s <output file>\n\n", argv[0]);
		return(1);
	}
	
	if ((fp=fopen(argv[1],"wb"))==NULL) 
	{
		fprintf(stderr, "\nCould not open '%s' for writing.\n\n", argv[1]);
		return(2);
	}
	/*
	** build header
	*/
	strcpy(cbs_hdr.cbs, "CBS");
	cbs_hdr.start=1;

	/*
	** read all files in stdin into structures
	*/
	for (i=0;i<ARRAYMAX;i++)
	{
		LOG("loop %d\n",i)
		zero_string(allrecs[i].fname,512);
		if (gets(allrecs[i].fname)==NULL)
		{
			/*
			** we've read the last one
			*/
			break;
		}
		LOG("read %s\n",allrecs[i].fname)

		/*
		** break fname into index, file name and class using ';' as spearator
		*/
		allrecs[i].index=i;
		pos=strchr(allrecs[i].fname,';');
		fnlen=strlen(allrecs[i].fname);
		if (pos!=NULL)
		{
			/*
			** if 1st field is numeric - then make it the index
			*/

			*pos=NUL;
			pos++;
			if (isnumeric(allrecs[i].fname))
			{
				sscanf(allrecs[i].fname,"%ld",&allrecs[i].index);
				/*
				** move rest of string to beginning of fname
				*/
				strcpy(tmp, pos);
				zero_string(allrecs[i].fname,fnlen);
				strcpy(allrecs[i].fname, tmp);
			}
			LOG("Index is %d\n", allrecs[i].index)
		}

		/*
		** proces fname and class
		*/
		pos=strchr(allrecs[i].fname,';');
		if (pos!=NULL)
		{
			/*
			** found a separator - change to \0
			** then add last component of fname onto class
			*/
			LOG("found ; at  %d\n",pos)

			*pos= (char) 0;
			pos++;
			for(j=pos-2;j>allrecs[i].fname;j--)
			{
				if (*j== '\\') break;
			}
			LOG("j is %d\n",j)
			LOG("pos is %d\n",pos)
			strcat(pos,j);

		}

	}

	/*
	** set the header count to # records
	*/

	cbs_hdr.last = i;

	/*
	** write the file
	*/

	fwrite(&cbs_hdr, sizeof(struct hdr), 1, fp);
	fwrite(allrecs, sizeof(struct rec), cbs_hdr.last, fp);

	fclose(fp);

	exit(0);

}
void zero_string(char *in, int len)
{
	char *s;
	int i;

	s=in;
	for(i=0;i<len;i++,s++)
	{
		*s = (char) 0;
	}
}
int isnumeric(char *str)
{
	char *s;

	for (s=str;*s!= NUL;s++)
		if (!isdigit(*s))
			return(0);
	return(1);
}
	
